package com.gct.centralbase.controller;


import com.gct.centralbase.service.CbPcProWellboreVolDailyService;
import com.gct.centralbase.service.CbTempWellMechDailyService;
import com.gct.centralbase.service.CbTempWellMechRuntimeService;
import com.gct.common.core.result.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;

import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 基础数据服务 前端控制器
 * </p>
 *
 * @author wsy
 * @since 2021-01-19
 */
@Api(value = "CentralBaseViewToolsController",description = "基础数据前端-更多工具")
@RestController
@RequestMapping("/view")
public class CentralBaseViewToolsController {

    @Autowired
    private CbPcProWellboreVolDailyService cbPcProWellboreVolDailyService;

    @Autowired
    private CbTempWellMechDailyService cbTempWellMechDailyService;

    @Autowired
    private CbTempWellMechRuntimeService cbTempWellMechRuntimeService;

    @ApiOperation(value = "getYieldCurve(获取生产曲线数据)", notes = "获取生产曲线数据")
    @GetMapping("/yieldCurve")
    public Result getYieldCurve(
            @ApiParam(name = "wellId",value = "井ID",required = true) @RequestParam("wellId") String wellId,
            @ApiParam(name = "beginDate",value = "开始时间（格式：YYYY-MM-dd）",required = true) @RequestParam("beginDate") String beginDate,
            @ApiParam(name = "endDate",value = "结束时间（格式：YYYY-MM-dd）",required = true) @RequestParam("endDate") String endDate){
        return cbPcProWellboreVolDailyService.getYieldCurve(wellId,beginDate,endDate);
    }

    @ApiOperation(value = "getLoadCurve(获取载荷曲线数据)", notes = "获取载荷曲线数据")
    @GetMapping("/loadCurve")
    public Result getLoadCurve(
            @ApiParam(name = "wellId",value = "井ID",required = true) @RequestParam("wellId") String wellId,
            @ApiParam(name = "beginTime",value = "开始时间（格式：YYYY-MM-dd HH:mm:ss）",required = true) @RequestParam("beginTime") String beginTime,
            @ApiParam(name = "endTime",value = "结束时间（格式：YYYY-MM-dd HH:mm:ss）",required = true) @RequestParam("endTime") String endTime){
        return cbTempWellMechDailyService.getLoadCurve(wellId,beginTime,endTime);
    }

    @ApiOperation(value = "分页查询功图平铺", notes = "分页查询油井功图平铺")
    @GetMapping("/tiled")
    public Result getTiledPaging(
            @ApiParam(name = "pageNum",value = "当前页",required = true) @RequestParam("pageNum") Integer pageNum,
            @ApiParam(name = "pageSize",value = "页大小",required = true) @RequestParam("pageSize") Integer pageSize,
            @ApiParam(name = "wellId",value = "井ID",required = true) @RequestParam("wellId") String wellId,
            @ApiParam(name = "beginTime",value = "开始时间（格式：YYYY-MM-dd HH:mm:ss）",required = true) @RequestParam("beginTime") String beginTime,
            @ApiParam(name = "endTime",value = "结束时间（格式：YYYY-MM-dd HH:mm:ss）",required = true) @RequestParam("endTime") String endTime
    ){
        return cbTempWellMechRuntimeService.getTiledPaging(pageNum,pageSize,wellId,beginTime,endTime);
    }

    @ApiOperation(value = "分页查询功图叠加", notes = "功图叠加：每天的功图叠加在一起显示")
    @GetMapping("/overlay")
    public Result getOverlayPaging(
            @ApiParam(name = "pageNum",value = "当前页",required = true) @RequestParam("pageNum") Integer pageNum,
            @ApiParam(name = "pageSize",value = "页大小",required = true) @RequestParam("pageSize") Integer pageSize,
            @ApiParam(name = "wellId",value = "井ID",required = true) @RequestParam("wellId") String wellId,
            @ApiParam(name = "beginTime",value = "开始时间（格式：YYYY-MM-dd HH:mm:ss）",required = true) @RequestParam("beginTime") String beginTime,
            @ApiParam(name = "endTime",value = "结束时间（格式：YYYY-MM-dd HH:mm:ss）",required = true) @RequestParam("endTime") String endTime
    ){
        return cbTempWellMechRuntimeService.getOverlayPaging(pageNum,pageSize,wellId,beginTime,endTime);
    }

    @ApiOperation(value = "getHistoryMeasures(获取历史措施数据)", notes = "获取历史措施数据")
    @GetMapping("/historyMeasures")
    public Result getHistoryMeasures(
            @ApiParam(name = "pageNum",value = "当前页",required = true) @RequestParam("pageNum") Integer pageNum,
            @ApiParam(name = "pageSize",value = "每页显示条数",required = true) @RequestParam("pageSize") Integer pageSize,
            @ApiParam(name = "wellId",value = "井Id",required = true) @RequestParam("wellId") String wellId,
            @ApiParam(name = "beginDate",value = "开始时间",required = true) @RequestParam("beginDate") String beginDate,
            @ApiParam(name = "endDate",value = "结束时间",required = true) @RequestParam("endDate") String endDate){
        return cbPcProWellboreVolDailyService.getHistoryMeasures(pageNum, pageSize,wellId,beginDate,endDate);
    }
}

