package com.gct.centralbase.entity;

import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import java.io.Serializable;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 油藏流体性质
 * </p>
 *
 * @author wsy
 * @since 2021-01-19
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@ApiModel(value="CbPcOilFluidProperty对象", description="油藏流体性质")
@TableName("centralbase.cb_pc_oil_fluid_property")
public class CbPcOilFluidProperty extends Model<CbPcOilFluidProperty> {

    private static final long serialVersionUID=1L;

    @ApiModelProperty(value = "层位ID")
    private String zoneId;

    @ApiModelProperty(value = "油品分类")
    private String oilProductClassification;

    @ApiModelProperty(value = "原油属性 石蜡基,中间基,环烷中间基,高含硫,环烷基原油.")
    private String crudeOilAttribute;

    @ApiModelProperty(value = "气顶气原始饱和度 原始含气饱和度%")
    private Double gasCapGasInitialSaturation;

    @ApiModelProperty(value = "气顶束缚水饱和度 气顶岩石中的不流动水在储层中所占的孔隙体积与储层总孔隙体积的比。公式：单井束缚水饱和度按有效厚度加权平均值%")
    private Double gasTopBoundWaterSaturation;

    @ApiModelProperty(value = "原始含油饱和度 %")
    private Double initialOilSaturation;

    @ApiModelProperty(value = "束缚水饱和度 油藏岩石中的不流动水在储层中所占的孔隙体积与储层总孔隙体积的比。公式：单井束缚水饱和度按有效厚度加权平均值%")
    private Double boundWaterSaturation;

    @ApiModelProperty(value = "地面原油密度kg/m3")
    private Double surfaceCrudeOilDensity;

    @ApiModelProperty(value = "地层原油密度kg/m3")
    private Double formationOilDensity;

    @ApiModelProperty(value = "气顶气密度kg/m3")
    private Double gasCapGasDensity;

    @ApiModelProperty(value = "溶解气密度kg/m^3")
    private Double dissolvedGasDensity;

    @ApiModelProperty(value = "地面原油粘度mPa*s")
    private Double surfaceCrudeOilViscosity;

    @ApiModelProperty(value = "地层原油粘度mPa*s")
    private Double formationOilViscosity;

    @ApiModelProperty(value = "气顶气粘度mPa*s")
    private Double gasCapGasViscosity;

    @ApiModelProperty(value = "气体积换算系数 该层位原始状态下的天然气与标准状况下天然气的体积比。公式：单井相对体积按有效厚度加权平均值")
    private Double gasVolumeConversionFactor;

    @ApiModelProperty(value = "压缩因子 在相同压力温度条件下实际气体占有的体积与理想气体所占体积之比")
    private Double compressionFactor;

    @ApiModelProperty(value = "地层原油体积系数  原油在地层条件下的体积与其在地面脱气后的体积之比。公式：单井地层原油体积系数按有效厚度加权平均值")
    private Double formationOilVolumeFactor;

    @ApiModelProperty(value = "地层原油压缩系数增减0.1MPa压力，单位体积地层原油体积变化率。公式：单井原油压缩系数按有效厚度加权平均值")
    private Double formationOilComprFactor;

    @ApiModelProperty(value = "凝固点 ℃  原油开始凝固的温度")
    private Double freezingPoint;

    @ApiModelProperty(value = "含蜡 %")
    private Double waxContent;

    @ApiModelProperty(value = "沥青质 %")
    private Double asphaltene;

    @ApiModelProperty(value = "胶质 %")
    private Double gelatine;

    @ApiModelProperty(value = "含硫 %")
    private Double sulphurContent;

    @ApiModelProperty(value = "水粘度 mPa*s")
    private Double waterViscosit;

    @ApiModelProperty(value = "水体积系数 m^3/m^3地层水在地层条件下的体积与其在地面标准状况下的体积之比")
    private Double waterVolumeFactor;

    @ApiModelProperty(value = "水压缩系数1/kPa 每增减0.1MPa压力，单位体积地层水体积变化率。公式：单井水压缩系数按有效厚度加权平均值")
    private Double waterCompressionFactor;

    @ApiModelProperty(value = "水热胀系数E-06/℃ 每立方地层水温度每提高一摄氏度体积的变化率")
    private Double waterThermalExpansionFactor;

    @ApiModelProperty(value = "氯离子含量ppm单位体积地层水中氯离子的重量。公式：单井氯根按有效厚度加权平均值")
    private Double chlorideIonContent;

    @ApiModelProperty(value = "地层水水型按苏林分类定义的水型，例如：CaCl2型，MgCl2型，CaCO3型等")
    private Double formationWaterType;

    @ApiModelProperty(value = "总矿化度 ppm单位体积地层水中所含各种离子，分子，化合物的总重量。公式：单井总矿化度按有效厚度加权平均值")
    private Double totalSalinity;

    @ApiModelProperty(value = "地层水电阻率ohm单井电阻率按有效厚度加权平均值")
    private Double formationWaterResistivity;

    @ApiModelProperty(value = "原油热容量KJ/m3℃每立方原油温度每提高一摄氏度所吸收的热量")
    private Double oilThermalCapacity;

    @ApiModelProperty(value = "原油热胀系数E-06/℃每立方原油温度每提高一摄氏度体积的变化率。公式：单井热膨涨系数按有效厚度加权平均值")
    private Double oilThermalExpansionFactor;

    @ApiModelProperty(value = "溶解气视体积系数")
    private Double dissolviedGasEVolFactor;

    @ApiModelProperty(value = "酸值1g石油产品中的酸性物质所需氢氧化钾毫克数。用表示油品对金属腐蚀性质及油品精制深度或变质程度。")
    private Double acidValues;

    @ApiModelProperty(value = "二氧化碳含量%CO2，天然气中的含量(mol)。无色无臭气体，有酸味。")
    private Double co2Content;

    @ApiModelProperty(value = "空气含量")
    private Double airOcntent;

    @ApiModelProperty(value = "地面原油初馏点1℃油样蒸馏过程中滴下第一个液滴时的温度。")
    private Double surfaceCrudeOilIbp1;

    @ApiModelProperty(value = "地面原油初馏点2℃油样蒸馏过程中滴下第二个液滴时的温度。")
    private Double surfaceCrudeOilIbp2;

    @ApiModelProperty(value = "原油粘度20℃mPa.s地面脱气油在20℃温度时所测的原油粘度值。")
    private Double crudeOilViscosity20;

    @ApiModelProperty(value = "原油粘度30℃mPa.s地面脱气油在30℃温度时所测的原油粘度值")
    private Double crudeOilViscosity30;

    @ApiModelProperty(value = "原油粘度40℃")
    private Double crudeOilViscosity40;

    @ApiModelProperty(value = "原油粘度50℃")
    private Double crudeOilViscosity50;

    @ApiModelProperty(value = "原油粘度80℃")
    private Double crudeOilViscosity80;

    @ApiModelProperty(value = "原油比热  原油单位重量下温度升高1℃时所需的热量。")
    private Double crudeOilSpecificHeat;

    @ApiModelProperty(value = "天然气地下粘度 天然气在地下条件下流动时所引起的内部摩擦阻力。")
    private Double naturalGasUndergroudViscosi;

    @ApiModelProperty(value = "甲烷含量%气测井中的甲烷的百分含量")
    private Double ch4Content;

    @ApiModelProperty(value = "乙烷含量%")
    private Double c2h6Content;

    @ApiModelProperty(value = "丙烷含量%")
    private Double c3h8Content;

    @ApiModelProperty(value = "丁烷含量%")
    private Double c4h10Content;

    @ApiModelProperty(value = "戊烷含量%")
    private Double c5h12Content;

    @ApiModelProperty(value = "氧气含量%")
    private Double o2Content;

    @ApiModelProperty(value = "氮气含量%")
    private Double n2Content;

    @ApiModelProperty(value = "硫化氢含量%")
    private Double h2sContent;

    @ApiModelProperty(value = "水比热水的单位重量下温度升高1℃时所需的热量")
    private Double waterSpecificHeat;

    @ApiModelProperty(value = "残余油饱和度%")
    private Double residualOilSaturation;

    @ApiModelProperty(value = "备注")
    private String comments;


    @Override
    protected Serializable pkVal() {
        return null;
    }

}
