package com.gct.centralbase.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gct.centralbase.entity.CbCdWellSource;
import com.gct.centralbase.mapper.CbCdWellSourceMapper;
import com.gct.centralbase.service.CbCdWellSourceService;
import com.gct.centralbase.service.CbPcOrganizationService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 单井基础信息 服务实现类
 * </p>
 *
 * @author wsy
 * @since 2021-01-19
 */
@Service
public class CbCdWellSourceServiceImpl extends ServiceImpl<CbCdWellSourceMapper, CbCdWellSource> implements CbCdWellSourceService {


    @Autowired
    private CbPcOrganizationService cbPcOrganizationService;


    /**
     * 获取井号数据
     *
     * @param orgid
     * @return
     */
    @Override
    public Result getWellSource(String orgid) {
        QueryWrapper<CbCdWellSource> queryWrapper = new QueryWrapper<>();
        QueryWrapper<CbCdWellSource> wrapper = queryWrapper.select(
                "well_id",
                "well_common_name",
                "well_legal_name",
                "reason",
                "well_purpose",
                "p_start_prod_stitum",
                "target_formation",
                "spud_date",
                "org_id",
                "struct_id",
                "oilfield_id",
                "exp_area_id",
                "group_unit_id",
                "station_id",
                "geo_latitude",
                "geo_longitude",
                "geo_offset_reference",
                "geo_offset_east",
                "geo_offset_north",
                "remarks",
                "is_deviated",
                "end_status",
                "completion_name",
                "PRODUCING_AREA_name",
                "top_tvd",
                "bottom_tvd",
                "completion_id").eq("org_id", orgid);
        List<Map<String, Object>> maps = baseMapper.selectMaps(wrapper);
        return Result.ok(maps);
    }


    /**
     * 根据组织架构Id获取井号数据
     *
     * @param orgid
     * @return
     */
    @Override
    public Result getjh(String orgid) {
        if (orgid.contains("["))
            orgid = JSONObject.parseArray(orgid).get(1).toString();
        List<String> orgidS = null;
        if (orgid != null && !"".equals(orgid)) {
            orgidS = cbPcOrganizationService.findAllIdById(orgid);
        }
        QueryWrapper<CbCdWellSource> wrapper = new QueryWrapper<>();
        wrapper.select("well_common_name", "well_id").in("org_id", orgidS);
        List<Map<String, Object>> mps = baseMapper.selectMaps(wrapper);
        //region deal fe -  data formatter
        mps = formatDataForFELoad(mps);
        //endregion
        return Result.ok(mps);
    }

    private List<Map<String, Object>> formatDataForFELoad(List<Map<String, Object>> mps) {
        List<Map<String, Object>> re = new ArrayList<>();
        if (mps.isEmpty() || mps.size() == 0) return re;
        for (Map<String, Object> mp : mps) {
            HashMap<String, Object> tmp = new HashMap<String, Object>();
            tmp.put("id", String.class.cast(mp.get("well_id")));
            tmp.put("value", String.class.cast(mp.get("well_common_name")));
            re.add(tmp);
        }
        return re;
    }

    @Override
    public Result searchWellsByOrgID(String seachText, String orgID) {
        if (orgID == null || orgID.isEmpty()) orgID = "0";
        if (orgID.contains("["))
            orgID = JSONObject.parseArray(orgID).get(1).toString();
        List<String> orgidS = null;
        if (orgID != null && !"".equals(orgID)) {
            orgidS = cbPcOrganizationService.findAllIdById(orgID);
        }
        QueryWrapper<CbCdWellSource> wrapper = new QueryWrapper<>();
        wrapper.select("well_common_name","well_id").in("org_id", orgidS).like("well_common_name", seachText)
                .orderByAsc("well_common_name").last("limit 10");
        List<Map<String, Object>> mps = baseMapper.selectMaps(wrapper);
        //region deal fe -  data formatter
        mps = formatDataForFELoad(mps);
        System.out.println(mps);
        //endregion
        return Result.ok(mps);
    }
    @Override
    public Result searchWellsByOrgID2(String seachText, String orgID) {
        JSONArray keys = JSONArray.parseArray(orgID);
        if(keys.size()<2) return Result.ok(new Object[]{});
        Integer level = Integer.class.cast(keys.get(0));
        String orgid=keys.get(1).toString();
        List<String> orgidS = null;
        if (orgID != null && !"".equals(orgID)) {
            orgidS = cbPcOrganizationService.findSubOrgIDWithMaxLevel(orgid,level);
        }
        QueryWrapper<CbCdWellSource> wrapper = new QueryWrapper<>();
        wrapper.select("well_common_name","well_id").in("org_id", orgidS).like("well_common_name", seachText)
                .orderByAsc("well_common_name").last("limit 10");
        List<Map<String, Object>> mps = baseMapper.selectMaps(wrapper);
        //region deal fe -  data formatter
        mps = formatDataForFELoad(mps);
        System.out.println(mps);
        //endregion
        return Result.ok(mps);
    }
    @Override
    public Result getByWellId(String wellId) {
        return Result.ok(baseMapper.selectOne(new QueryWrapper<CbCdWellSource>().eq("well_id",wellId)));
    }

   /* @Override
    public Result getWellInfo(Integer curPage,Integer pageSize) {
        System.out.println(curPage+","+pageSize);
        IPage<CbCdWellSource> page = new Page<>(curPage,pageSize);
        List<CbCdWellSource> wellInfoList = baseMapper.selectPage(page, new QueryWrapper<CbCdWellSource>()).getRecords();
        return Result.ok(wellInfoList);
    }*/

    @Override
    public Result getWellInfo(Integer curPage, Integer pageSize){
        int minLevel=1;
        Integer maxLevel=cbPcOrganizationService.getMaxLevelFromOrg();
        if(maxLevel==null) return null;
        String sql="select t.well_id,t.well_common_name,t.spud_date,t2.org_id level3,t2.org_name level_name3,t2.parent_id level3_parent_id from centralbase.cb_cd_well_source t left join centralbase.cb_pc_organization t2 on t.org_id=t2.org_id";
        for (int i = maxLevel-1; i >=minLevel ; i--) {
            sql=" select  m"+i+".*, m"+i+"2.org_id level"+i+",m"+i+"2.org_name level_name"+i+",m"+i+"2.parent_id level"+i+"_parent_id from ("+sql+") m"+i+" left join centralbase.cb_pc_organization m"+i+"2 on m"+i+".level"+(i+1)+"_parent_id=m"+i+"2.org_id";
        }
        System.out.println(sql);
        Page<Map<String, Object>> page = baseMapper.getAllWellSourceList(new Page<Map<String, Object>>(curPage, pageSize), sql);
        return Result.ok(page.getRecords());
    }
}
