package com.gct.centralbase.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.gct.centralbase.entity.CbPcOrganization;
import com.gct.centralbase.mapper.CbPcOrganizationMapper;
import com.gct.centralbase.service.CbPcOrganizationService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 组织机构 服务实现类
 * </p>
 *
 * @author wsy
 * @since 2021-01-19
 */
@Service
public class CbPcOrganizationServiceImpl extends ServiceImpl<CbPcOrganizationMapper, CbPcOrganization> implements CbPcOrganizationService {

    @Override
    public Result findTree() {
        QueryWrapper<CbPcOrganization> wrapper = new QueryWrapper<>();
        wrapper.eq("parent_id", "")
                .or()
                .eq("parent_id", "0")
                .or()
                .isNull("parent_id");
        // 得到一级节点资源列表
        List<CbPcOrganization> resources = baseMapper.selectList(wrapper);
        if (resources != null && resources.size() > 0) {
            resources.forEach(this::findAllChild);
        }

        return Result.ok(resources);
    }

    /**
     * 递归查询子部门
     *
     * @param cbPcOrganization
     */
    private void findAllChild(CbPcOrganization cbPcOrganization) {
        QueryWrapper<CbPcOrganization> wrapper = new QueryWrapper<>();
        wrapper.eq("parent_id", cbPcOrganization.getOrgId());
        // 首次进入这个方法时，查出的是二级节点列表
        // 递归调用时，就能依次查出三、四、五等等级别的节点列表，
        // 递归能实现不同节点级别的无限调用,这个层次不易太深，否则有性能问题
        List<CbPcOrganization> resources = baseMapper.selectList(wrapper);
        cbPcOrganization.setChildren(resources);
        if (resources != null && resources.size() > 0) {
            resources.forEach(this::findAllChild);
        }
    }

    private final String[] columnName = {"org_id", "org_name", "org_level"};
    private final String colParentId = "parent_id";

    /**
     * 获取组织架构数据
     *
     * @return
     */
    @Override
    public Result getOrganization(String parent_id) {

        List<Map<String, Object>> records = null;
//        int currentLevel = 0;
        String defaultItemID = "";
        if (parent_id == null || parent_id.equals("0")) {
            parent_id = "0";//init parent id and set value 0
            records = getOrgChildrenByParent(parent_id);
            defaultItemID = "[0,0,1]";
        } else if (parent_id.contains("[")) {
            /* ps:
             * must to be declared with array parameter, then could select children
             * parent id start with 1 actually,but global default parent id is 0
             * @array parameter: [parent id level(start with 1 and self++),parent id,current level]
             */
            List<Integer> li = JSONObject.parseArray(parent_id, Integer.class);
            Integer parentLevel = li.get(0);
            Integer nextLevel = li.get(2) + 1;
            while (parentLevel < nextLevel) {
                if (records == null)
                    records = getOrgChildrenByParent(li.get(1).toString());
                else {
                    List<Map<String, Object>> nextLevelRecords = new ArrayList<>();
                    for (Map<String, Object> record : records) {
                        List<Map<String, Object>> children = getOrgChildrenByParent(record.get(columnName[0]).toString());
                        nextLevelRecords.addAll(children);
                    }
                    records.clear();
                    records.addAll(nextLevelRecords);
                }
                parentLevel += 1;
            }
            li.set(2, nextLevel);
            defaultItemID = JSONObject.toJSONString(li.toArray());
        } else {
            records = getOrgChildrenByParent(parent_id);
            if (records != null && records.size() > 0) {
                Map<String, Object> re = records.get(0);
                Integer curLevel = Integer.class.cast(re.get(columnName[2]));
                defaultItemID = "[" + (curLevel - 1) + "," + parent_id + "," + curLevel + "]";
            }
        }

        if (records != null && records.size() > 1) {
            Map<String, Object> showAllItem = new HashMap<>();
            showAllItem.put(columnName[0], defaultItemID);
            showAllItem.put(columnName[1], "全部");
            records.add(0, showAllItem);
        }
        return Result.ok(records);
    }

    /**
     * simple fun getOrgChildrenByParent
     * Author:  lloyd
     *
     * @param parent_id
     * @return
     */
    private List<Map<String, Object>> getOrgChildrenByParent(String parent_id) {
        QueryWrapper<CbPcOrganization> queryWrapper = new QueryWrapper<>();
        queryWrapper.select(columnName).eq(colParentId, parent_id);
        System.out.println(JSONObject.toJSONString(baseMapper.selectMaps(queryWrapper)));
        return baseMapper.selectMaps(queryWrapper);
    }

    /**
     * 通过id查询该部门下的所有子部门id 列表
     *
     * @param id
     * @return
     */
    @Override
    public List<String> findAllIdById(String id) {
        int org_level = 0;
        if (id == null || id == "0") id = "0";
        else {
            CbPcOrganization orgInput = baseMapper.selectOne(new QueryWrapper<CbPcOrganization>().eq("org_id", id));
            if (orgInput != null) org_level = orgInput.getOrgLevel();
        }
        return findSubOrgIDWithMaxLevel(id, org_level);
    }

    @Override
    public List<CbPcOrganization> getOrgId(String orgId) {
        return baseMapper.getOrgId(orgId);
    }

    @Override
    public CbPcOrganization getOrgById(String id) {
        return baseMapper.selectOne(new QueryWrapper<CbPcOrganization>().eq("org_id", id));
    }


    /**
     * 递归查询所有子部门Id
     *
     * @param id
     * @param list
     */
    private void findIds(String id, List<String> list) {
        list.add(id);
        QueryWrapper<CbPcOrganization> wrapper = new QueryWrapper<>();
        wrapper.eq("parent_id", id);
        List<CbPcOrganization> resources = baseMapper.selectList(wrapper);
        if (resources != null && resources.size() > 0) {
            resources.stream().forEach(CbPcOrganization -> {
                this.findIds(CbPcOrganization.getOrgId(), list);
            });
        }
    }

    @Override
    public Integer getMaxLevelFromOrg() {
        List<Map<String, Object>> one = baseMapper.selectMaps(new QueryWrapper<CbPcOrganization>().select("max(org_level) org_level"));
        if (one == null || one.size() == 0) return null;
        Integer maxLevel = Integer.class.cast(one.get(0).get("org_level"));
        return maxLevel;
    }

    @Override
    public List<String> findSubOrgIDWithMaxLevel(String id, int level) {

        Integer maxLevel = getMaxLevelFromOrg();
        if (maxLevel == null) return null;
        List<String> ids = new ArrayList<>();
        if (maxLevel == level) {
            ids.add(id);
            return ids;
        }
        String sql = "select org_id from centralbase.cb_pc_organization  where parent_id='" + id + "'";
        for (int i = 0; i < maxLevel - level - 1; i++) {
            sql = "select t" + i + "2.org_id from (" + sql + ") t" + i + " left join centralbase.cb_pc_organization t" + i + "2 on t" + i + ".org_id=t" + i + "2.parent_id";
        }
        System.out.println("sql = " + sql);
        List<CbPcOrganization> res = baseMapper.getSubOrgIDsWithMaxLevel(sql);

        res.forEach((x) -> {
            if (x != null && x.getOrgId() != null && !x.getOrgId().isEmpty())
                ids.add(x.getOrgId());
        });

        return ids;
    }


}
