package com.gct.centralbase.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gct.centralbase.entity.CbPcProWellboreStatusDaily;
import com.gct.centralbase.entity.CbPcProWellboreVolDaily;
import com.gct.centralbase.mapper.CbPcProWellboreStatusDailyMapper;
import com.gct.centralbase.mapper.CbPcProWellboreVolDailyMapper;
import com.gct.centralbase.service.CbCdWellSourceService;
import com.gct.centralbase.service.CbPcOrganizationService;
import com.gct.centralbase.service.CbPcProWellboreVolDailyService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;

/**
 * <p>
 * 采出井井筒生产日数据 服务实现类
 * </p>
 *
 * @author wsy
 * @since 2021-01-19
 */
@Service
public class CbPcProWellboreVolDailyServiceImpl extends ServiceImpl<CbPcProWellboreVolDailyMapper, CbPcProWellboreVolDaily> implements CbPcProWellboreVolDailyService {

    @Autowired
    private CbPcProWellboreVolDailyMapper cbPcProWellboreVolDailyMapper;

    @Autowired
    private CbPcProWellboreStatusDailyMapper cbPcProWellboreStatusDailyMapper;

    @Autowired
    private CbCdWellSourceService cbCdWellSourceService;

    @Autowired
    private CbPcOrganizationService cbPcOrganizationService;



    private DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");


    @Override
    public Result getYieldCurve(String wellId, String beginDate, String endDate) {
        //生产曲线查询  液量、油量、含水
        LocalDateTime begin = LocalDateTime.parse(beginDate.length() == 10 ? beginDate + " 00:00:00" : beginDate, df);
        LocalDateTime end = LocalDateTime.parse(endDate.length() == 10 ? endDate + " 00:00:00" : endDate, df);
        QueryWrapper<CbPcProWellboreVolDaily> queryWrapper = new QueryWrapper<>();
        queryWrapper.select(
                "prod_date",
                "liq_prod_daily",
                "oil_prod_daily",
                "water_cut")
                .ge("prod_date", begin)
                .le("prod_date", end)
                .eq("well_id", wellId)
                .orderByAsc("prod_date");
        //动液面查询  动液面
        QueryWrapper<CbPcProWellboreStatusDaily> queryWrapper1 = new QueryWrapper<>();
        QueryWrapper<CbPcProWellboreStatusDaily> wrapper1 = queryWrapper1.select("well_id", "prod_date", "start_pump_liq_level")
                .ge("prod_date", begin)
                .le("prod_date", end)
                .eq("well_id", wellId)
                .orderByAsc("prod_date");
        List<CbPcProWellboreVolDaily> volDailies = cbPcProWellboreVolDailyMapper.selectList(queryWrapper);
        List<CbPcProWellboreStatusDaily> mechDailies = cbPcProWellboreStatusDailyMapper.selectList(wrapper1);
        //封装结果集
        LinkedHashMap<String, Object> resultMap = new LinkedHashMap<>();
        //第一个eCharts图表
        LinkedHashMap<String, Object> eCharts1 = new LinkedHashMap<>();
        //第二个eCharts图表
        LinkedHashMap<String, Object> eCharts2 = new LinkedHashMap<>();
        //横坐标
        List<String> x1Date = new ArrayList<>();
        List<String> x2Date = new ArrayList<>();
        //日产液量
        LinkedHashMap<String, Object> eCharts1Liq = new LinkedHashMap<>();
        List<Double> eCharts1LiqData = new ArrayList<>();
        //日产油量
        LinkedHashMap<String, Object> eCharts1Oil = new LinkedHashMap<>();
        List<Double> eCharts1OilData = new ArrayList<>();
        //含水率
        LinkedHashMap<String, Object> eCharts1Water = new LinkedHashMap<>();
        List<Double> eCharts1WaterData = new ArrayList<>();
        //动液面
        LinkedHashMap<String, Object> eCharts2Level = new LinkedHashMap<>();
        List<Double> eCharts2LevelData = new ArrayList<>();
        //遍历
        volDailies.forEach((cbPcProWellboreVolDaily) -> {
            eCharts1LiqData.add(cbPcProWellboreVolDaily.getLiqProdDaily());
            eCharts1OilData.add(cbPcProWellboreVolDaily.getOilProdDaily());
            eCharts1WaterData.add(cbPcProWellboreVolDaily.getWaterCut());
            x1Date.add(DateTimeFormatter.ofPattern("yyyy-MM-dd").format(cbPcProWellboreVolDaily.getProdDate()));
        });
        mechDailies.forEach((cbPcProWellboreStatusDaily -> {
            x2Date.add(DateTimeFormatter.ofPattern("yyyy-MM-dd").format(cbPcProWellboreStatusDaily.getProdDate()));
            eCharts2LevelData.add(cbPcProWellboreStatusDaily.getStartPumpLiqLevel());
        }));
        //组装数据
        eCharts1Liq.put("name", "日产液量");
        eCharts1Liq.put("data", eCharts1LiqData);
        eCharts1Liq.put("unit", "t");
        eCharts1Oil.put("name", "日产油量");
        eCharts1Oil.put("data", eCharts1OilData);
        eCharts1Oil.put("unit", "t");
        eCharts1Water.put("name", "含水率");
        eCharts1Water.put("data", eCharts1WaterData);
        eCharts1Water.put("unit", "%");
        eCharts1.put("xAxis", x1Date);
        eCharts1.put("series", new Object[]{eCharts1Liq, eCharts1Oil, eCharts1Water});
        eCharts2Level.put("name", "动液面");
        eCharts2Level.put("unit", "m");
        eCharts2Level.put("data", eCharts2LevelData);
        eCharts2.put("xAxis", x2Date);
        eCharts2.put("series", new Object[]{eCharts2Level});
        resultMap.put("eCharts1", eCharts1);
        resultMap.put("eCharts2", eCharts2);
        return Result.ok(resultMap);
    }

    @Override
    public Result getHistoryMeasures(Integer pageNum, Integer pageSize, String wellId, String beginDate, String endDate) {
        //分页插件
        Page<Map<String, Object>> paramPage = new Page<>(pageNum, pageSize);
        paramPage.offset();
        paramPage.addOrder(OrderItem.asc("prod_date"));
        LocalDateTime begin = LocalDateTime.parse(beginDate.length() == 10 ? beginDate + " 00:00:00" : beginDate, df);
        LocalDateTime end = LocalDateTime.parse(endDate.length() == 10 ? endDate + " 00:00:00" : endDate, df);
        QueryWrapper<CbPcProWellboreVolDaily> queryWrapper = new QueryWrapper<>();
        queryWrapper.select(
                "well_id",
                "prod_date",
                "stim_content")
                .ge("prod_date", begin)
                .le("prod_date", end)
                .eq("well_id", wellId);
        Page<Map<String, Object>> page = cbPcProWellboreVolDailyMapper.selectMapsPage(paramPage, queryWrapper);
        List<Map<String, Object>> records = page.getRecords();
        records.forEach((map) -> {
            map.put("well_id", map.get("well_id"));
            map.put("prod_date", df.format(((Timestamp) map.get("prod_date")).toLocalDateTime()));
            map.put("stim_content", map.get("stim_content"));
        });
        return Result.ok(page);
    }

    @Override
    public Result getWellBoreVolDaily(String wellId, String prodDate) {
        return Result.ok(cbPcProWellboreVolDailyMapper.getWellBoreVolDaily(wellId,prodDate));
    }

    @Override
    public CbPcProWellboreVolDaily getA2DataForCalVolDaily(String wellName, String dataTime) {
        return cbPcProWellboreVolDailyMapper.getA2DataForCalVolDaily(wellName,dataTime);
    }

    @Override
    public Result getCbPcProWellBoreVolDaily(String prodDate,Integer curPage,Integer pageSize) {
        return Result.ok(cbPcProWellboreVolDailyMapper.getCbPcProWellBoreVolDaily(prodDate,curPage,pageSize));
    }

    /*@Override
    public Result getCbPcProWellBoreVolDailyCount(String prodDate) {
        List<CbPcProWellboreVolDaily> cbPcProWellboreVolDailies = cbPcProWellboreVolDailyMapper.getCbPcProWellBoreVolDailyCount(prodDate);
        List<CbCdWellSource> cbCdWellSources = cbCdWellSourceService.list();
        List<CbPcOrganization> cbPcOrganizations = cbPcOrganizationService.list();
        Map<String, String> wellToOrgMap = new HashMap<>();
        Map<String, CbPcOrganization> orgIdToOrgMap = new HashMap<>();
        cbPcOrganizations.forEach(x->orgIdToOrgMap.put(x.getOrgId(),x));
        cbCdWellSources.forEach(x->wellToOrgMap.put(x.getWellId(),x.getOrgId()));
        Map<String,Integer> planCountMap = new HashMap<>();
        Map<String,Integer> curCountMap = new HashMap<>();
        cbPcProWellboreVolDailies.forEach(x->{
            String orgId = wellToOrgMap.get(x.getWellId());
            String orgName = "";
            while (true){
                CbPcOrganization cbPcOrganization = orgIdToOrgMap.get(orgId);
                if (cbPcOrganization.getOrgLevel()==1){
                    orgName = cbPcOrganization.getOrgName();
                    break;
                }
                orgId = cbPcOrganization.getParentId();
            }
            Integer planCount = planCountMap.get(orgName);
            planCountMap.put(orgName,planCount==null?1:planCount+1);
            if(x.getProdTime()>0){
                Integer curCount = curCountMap.get(orgName);
                curCountMap.put(orgName,curCount==null?1:curCount+1);
            }
        });
        JSONArray jsonArray = new JSONArray();
        planCountMap.forEach((k,v)->{
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("workArea",k);
            jsonObject.put("planCount",v);
            Integer curCount = curCountMap.get(k);
            jsonObject.put("curCount" ,curCount==null?0:curCount);
            jsonArray.add(jsonObject);
        });
        return Result.ok(jsonArray);
    }*/


}
