package com.gct.centralbase.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.gct.centralbase.entity.CbTempWellMechDaily;
import com.gct.centralbase.mapper.CbTempWellMechDailyMapper;
import com.gct.centralbase.service.CbTempWellMechDailyService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;

/**
 * <p>
 * 机采数据 daily 服务实现类
 * </p>
 *
 * @author wsy
 * @since 2021-01-19
 */
@Service
public class CbTempWellMechDailyServiceImpl extends ServiceImpl<CbTempWellMechDailyMapper, CbTempWellMechDaily> implements CbTempWellMechDailyService {

    @Autowired
    private CbTempWellMechDailyMapper cbTempWellMechDailyMapper;

    @Override
    public Result getLoadCurve(String wellId, String beginTime, String endTime) {
        //载荷曲线
        QueryWrapper<CbTempWellMechDaily> queryWrapper = new QueryWrapper<>();
        DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        LocalDateTime begin = LocalDateTime.parse(beginTime, df);
        LocalDateTime end = LocalDateTime.parse(endTime, df);
        QueryWrapper<CbTempWellMechDaily> wrapper = queryWrapper.select("prod_date", "susp_max_load", "susp_min_load")
                .ge("prod_date", begin)
                .le("prod_date", end)
                .eq("well_id", wellId)
                .orderByAsc("prod_date");
        List<CbTempWellMechDaily> mechDailies = cbTempWellMechDailyMapper.selectList(wrapper);
        //封装结果集
        LinkedHashMap<String, Object> resultMap = new LinkedHashMap<>();
        //横坐标
        List<String> xDate = new ArrayList<>();
        //最大载荷
        LinkedHashMap<String, Object> maxLoad = new LinkedHashMap<>();
        List<Double> maxLoadData = new ArrayList<>();
        //最小载荷
        LinkedHashMap<String, Object> minLoad = new LinkedHashMap<>();
        List<Double> minLoadData = new ArrayList<>();
        mechDailies.forEach(cbTempWellMechDaily -> {
            xDate.add(df.format(cbTempWellMechDaily.getProdDate()));
            maxLoadData.add(cbTempWellMechDaily.getSuspMaxLoad());
            minLoadData.add(cbTempWellMechDaily.getSuspMinLoad());
        });
        maxLoad.put("name","最大载荷");
        maxLoad.put("data",maxLoadData);
        maxLoad.put("unit","KN");
        minLoad.put("name","最小载荷");
        minLoad.put("data",minLoadData);
        minLoad.put("unit","KN");
        resultMap.put("xAxis",xDate);
        resultMap.put("series",new Object[]{maxLoad,minLoad});
        return Result.ok(resultMap);
    }

    @Override
    public Result getWellMechDaily(String wellId, String prodDate) {
        return Result.ok(cbTempWellMechDailyMapper.getWellMechDaily(wellId,prodDate));
    }
}
