package com.gct.centralbase.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gct.centralbase.entity.CbTempWellMechRuntime;
import com.gct.centralbase.mapper.CbTempWellMechRuntimeMapper;
import com.gct.centralbase.service.CbTempWellMechRuntimeService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import com.gct.common.util.SGTUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 机采数据 runtime 服务实现类
 * </p>
 *
 * @author wsy
 * @since 2021-01-19
 */
@Service
public class CbTempWellMechRuntimeServiceImpl extends ServiceImpl<CbTempWellMechRuntimeMapper, CbTempWellMechRuntime> implements CbTempWellMechRuntimeService {

    private DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
    private DateTimeFormatter dfDay = DateTimeFormatter.ofPattern("yyyy-MM-dd");

    @Override
    public Result getTiledPaging(Integer pageNum, Integer pageSize, String wellId, String beginTime, String endTime) {
        //分页插件
        Page<Map<String, Object>> paramPage = new Page<>(pageNum, pageSize);
        paramPage.offset();
        paramPage.addOrder(OrderItem.asc("prod_date"));
        //查询条件
        QueryWrapper<CbTempWellMechRuntime> queryWrapper = new QueryWrapper<>();
        LocalDateTime begin = LocalDateTime.parse(beginTime, df);
        LocalDateTime end = LocalDateTime.parse(endTime, df);
        QueryWrapper<CbTempWellMechRuntime> wrapper = queryWrapper.select("prod_date", "sgt")
                .ge("prod_date", begin)
                .le("prod_date", end)
                .eq("well_id", wellId);
        Page<Map<String, Object>> page = baseMapper.selectMapsPage(paramPage, wrapper);
        //格式化功图数据
        List<Map<String, Object>> records = page.getRecords();
        records.forEach((map) -> {
            map.put("sgt", SGTUtil.encodeToView((String) map.get("sgt")));
            map.put("prod_date", df.format(((Timestamp) map.get("prod_date")).toLocalDateTime()));
        });
        return Result.ok(page);
    }

    @Override
    public Result getOverlayPaging(Integer pageNum, Integer pageSize, String wellId, String beginTime, String endTime) {
        //分页插件
        Page<Map<String, Object>> paramPage = new Page<>(pageNum, pageSize);
        paramPage.offset();
        //查询条件
        QueryWrapper<CbTempWellMechRuntime> dateWrapper = new QueryWrapper<>();
        //开始-结束时间
        LocalDateTime begin = LocalDateTime.parse(beginTime, df);
        LocalDateTime end = LocalDateTime.parse(endTime, df);
        //自算分组并分页处理 按天分组 然后分页，查询当前页对应日期范围的数据
        dateWrapper
                .select("to_char ( prod_date, 'YYYY-MM-DD' ) AS day")
                .ge("prod_date", begin)
                .le("prod_date", end)
                .eq("well_id", wellId)
                .groupBy("day")
                .orderByAsc("day");
        Page<Map<String, Object>> page = baseMapper.selectMapsPage(paramPage, dateWrapper);
        List<Map<String, Object>> tempRecords = page.getRecords();
        //查询当前页的数据
        QueryWrapper<CbTempWellMechRuntime> queryWrapper = new QueryWrapper<>();
        queryWrapper.select("prod_date", "sgt")
                .ge("to_char ( prod_date, 'YYYY-MM-DD' )", tempRecords.get(0).get("day"))
                .le("to_char ( prod_date, 'YYYY-MM-DD' )", tempRecords.get(tempRecords.size() - 1).get("day"))
                .eq("well_id", wellId)
                .orderByAsc("prod_date");
        List<Map<String, Object>> maps = baseMapper.selectMaps(queryWrapper);
        //格式化并组装数据
        List<Map<String, Object>> records = new ArrayList<>();
        tempRecords.forEach(tempMap -> {
            Map<String, Object> record = new HashMap<>();
            Object day = tempMap.get("day");
            record.put("day", day);
            List<Map<String, Object>> details = new ArrayList<>();
            maps.forEach(map -> {
                if (day.equals(dfDay.format(((Timestamp) map.get("prod_date")).toLocalDateTime()))) {
                    Map<String, Object> detail = new HashMap<>();
                    detail.put("prod_date", df.format(((Timestamp) map.get("prod_date")).toLocalDateTime()));
                    detail.put("sgt", SGTUtil.encodeToView((String) map.get("sgt")));
                    details.add(detail);
                }
            });
            record.put("details", details);
            records.add(record);
        });
        page.setRecords(records);
        return Result.ok(page);
    }

    @Override
    public Result getAllRuntimeData() {
        List<CbTempWellMechRuntime> list = this.getBaseMapper().selectPage(new Page<CbTempWellMechRuntime>(1,30000),null)
                .getRecords().stream().filter(x -> x.getProdDate() != null).collect(Collectors.toCollection(ArrayList::new));
        /*list.forEach(x->{
            if (x.getProdDate()==null||x.getSgt()==null){
                System.out.println(x.getProdDate()+","+x.getSgt());
            }
        });*/
        return Result.ok(list);
    }
}
